# Online grocery stores

* [x] https://www.walmart.ca/en/grocery/
* [x] https://realcanadiansuperstore.ca/
* [x] https://www.loblaws.ca/
* [x] https://www.zehrs.ca/
* [x] https://www.valumart.ca/
* [ ] https://www.wholesaleclub.ca/
* [ ] https://www.instacart.ca/
* [ ] https://www.grocerygateway.com/
* [ ] https://www.metro.ca/